@@ -5,8 +5,10 @@
 # The commands used by this script are limited to the ones available on
 # the root floppy.
 
+#set -x
 set -e
 umask 022
+retcode=0
 
 extract="cpio --format=ustar --extract --unconditional"
 if [ -x /bin/star -o -x /usr/bin/star ]; then
@@ -25,7 +27,23 @@ if [ $# -gt 0 ]; then
 	DESTDIR=$1
 fi
 
-(cd ${DESTDIR}/; gunzip < $FLOPPY/modules.tgz|$extract)
-(cd ${DESTDIR}/; depmod -a)
+(cd ${DESTDIR}/; zcat < $FLOPPY/modules.tgz|$extract)
+#(cd ${DESTDIR}/; depmod -a)
+
+#mv ${DESTDIR}/bin/mount ${DESTDIR}/bin/mount.old
+#mv ${DESTDIR}/bin/umount ${DESTDIR}/bin/umount.old
+
+#set +e 
+#(cd ${DESTDIR}/; zcat < $FLOPPY/nettools.tgz|$extract)
+
+#for i in mount umount; do
+#	if [ ! -x ${DESTDIR}/bin/$i ]; then
+#		mv ${DESTDIR}/bin/$i.old ${DESTDIR}/bin/$i
+#		retcode=-1
+#	else
+#		rm -f ${DESTDIR}/bin/$i.old
+#	fi
+#done
+
 sync
-exit 0
+exit $retcode
