@@ -5,10 +5,11 @@
 # The commands used by this script are limited to the ones available on
 # the root floppy.
 
+#set -x
 set -e
 umask 022
 
-VERSION=--version--
+VERSION=__version__
 
 extract="cpio --format=ustar --extract --unconditional"
 if [ -x /bin/star -o -x /usr/bin/star ]; then
@@ -36,7 +37,9 @@ rdev ${DESTDIR}/boot/vmlinuz-${VERSION} ${DESTDIR}
 rdev -r ${DESTDIR}/boot/vmlinuz-${VERSION} 0
 rdev -R ${DESTDIR}/boot/vmlinuz-${VERSION} 1
 rdev -v ${DESTDIR}/boot/vmlinuz-${VERSION} -1
-gunzip < sys_map.gz > ${DESTDIR}/boot/System.map-${VERSION}
+if [ -f sys_map.gz ]; then
+	zcat < sys_map.gz > ${DESTDIR}/boot/System.map-${VERSION}
+fi
 if [ -f ${DESTDIR}/vmlinuz ]; then 
 	rm -f ${DESTDIR}/vmlinuz.old
 	mv -f ${DESTDIR}/vmlinuz ${DESTDIR}/vmlinuz.old
@@ -48,6 +51,6 @@ if [ -f ${DESTDIR}/System.map ]; then
 	mv -f ${DESTDIR}/System.map ${DESTDIR}/System.old
 	rm -f ${DESTDIR}/System.map
 fi
-(cd ${DESTDIR}/; ln -s boot/System.map-${VERSION} System.map)
+(cd ${DESTDIR}/; ln -s -f boot/System.map-${VERSION} System.map)
 sync
 exit 0
