@@ -1,6 +1,9 @@
 #include "internal.h"
 #include <sys/ioctl.h>
 #include <linux/fd.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 
 const char			fdflush_usage[] = "fdflush device";
 
