@@ -2,12 +2,14 @@
 #include <stdio.h>
 #include <sys/stat.h>
 #include <sys/param.h>
+#include <errno.h>
 
-const char	ln_usage[] = "ln [-s] original-name additional-name\n"
+const char	ln_usage[] = "ln [-s] [-f] original-name additional-name\n"
 "\n"
 "\tAdd a new name that refers to the same file as \"original-name\"\n"
 "\n"
-"\t-s:\tUse a \"symbolic\" link, instead of a \"hard\" link.\n";
+"\t-s:\tUse a \"symbolic\" link, instead of a \"hard\" link.\n"
+"\t-f:\tRemove existing destination files.\n";
 
 int
 ln_fn(const struct FileInfo * i)
@@ -32,7 +34,7 @@ ln_fn(const struct FileInfo * i)
 	}
 
 	if ( i->force )
-		status = ( unlink(destination) == 0 || errno != ENOENT );
+		status = ( unlink(destination) && errno != ENOENT );
 
 	if ( status == 0 ) {
 		if ( i->makeSymbolicLink )
