@@ -1,9 +1,10 @@
 #include "internal.h"
 #include <stdio.h>
 #include <string.h>
+#include <errno.h>
 
 static const struct Applet	applets[] = {
-{ "block_device",block_device_main,0,	block_device_usage,1,1	},
+{ "block_device",block_device_main,	0,	block_device_usage,1,1	},
 { "cat",	cat_more_main,	cat_fn,		cat_usage,		0,	-1	},
 { "chgrp",	chgrp_main,		0,			chgrp_usage,	2,	-1	},
 { "chmod",	chmod_main,		0,			chmod_usage,	2,	-1	},
@@ -11,15 +12,19 @@ static const struct Applet	applets[] = {
 { "clear",	clear_main,		0,			clear_usage,	0,	 0	},
 { "cp",		dyadic_main,	cp_fn,		cp_usage,		2,	-1	},
 { "date",	date_main,		0,			date_usage,		0,	 0	},
+{ "dd",		dd_main,		0,			dd_usage,	0,	2	},
 { "df",		df_main,		0,			df_usage,		0,	-1	},
+{ "dmesg",	dmesg_main,		0,			dmesg_usage,		0,	 0	},
 { "false",	false_main,		0,			false_usage,	0,	 0	},
 { "fdflush",monadic_main,	fdflush_fn,	fdflush_usage,	1,	-1	},
+{ "find",		find_main,	find_fn,    find_usage,	1,	-1 },
 { "floppy_merge",floppy_merge_main,0,	floppy_merge_usage,	1,	1 },
 { "halt",	halt_main,		0,			halt_usage,		0,	 0	},
 { "init",	init_main,		0,			init_usage,		0,	-1	},
 { "kill",	kill_main,		0,			kill_usage,		1,	-1	},
 { "length",	length_main,	0,			length_usage,	1,	 1	},
 { "ln",		dyadic_main,	ln_fn,		ln_usage,		2,	-1	},
+{ "losetup",	losetup_main,	0,			losetup_usage,	1,	2	},
 { "ls",		ls_main,		0,			ls_usage,		0,	-1	},
 { "math",	math_main,		0,			math_usage,		1,	-1	},
 { "mkdir",	monadic_main,	mkdir_fn,	mkdir_usage,	1,	-1	},
@@ -43,6 +48,7 @@ static const struct Applet	applets[] = {
 { "tryopen",tryopen_main,	0,			tryopen_usage,	0,	-1	},
 { "umount",	umount_main,	0,			umount_usage,	1,	-1	},
 { "update",	update_main,	0,			update_usage,	0,	-1	},
+{ "zcat",	zcat_main,	0,			zcat_usage,	0,	-1	},
 { 0 }
 };
 
