@@ -7,5 +7,10 @@ const char	swapon_usage[] = "swapon block-device\n"
 extern int
 swapon_fn(const struct FileInfo * i)
 {
+#ifdef sparc
+        return swapon(i->source);
+#else
 	return swapon(i->source, 0);
+#endif
 }
+
